==> opennebula_3.2.1.orig.tar.gz: opennebula-3.2.1/src/cloud/occi/lib/ui/public/locale/en_US/en_US.js <==
//Translated by
lang="en_US"
datatable_lang=""
locale={
    "Additionally, OpenNebula Self-Service allows easy customization of the interface (e.g. this text) and brings multi-language support.":"",
    "Additionally, you can run several operations on defined storages, such as defining their persistance. Persistent images can only be used by 1 virtual machine, and the changes made by it have effect on the base image. Non-persistent images are cloned before being used in a Virtual Machine, therefore changes are lost unless a snapshot is taken prior to Virtual Machine shutdown.":"",
    "Additionally, you can take a \'snapshot\' of the storage attached to these resources. They will be saved as new resources, visible from the Storage view and re-usable.":"",
    "Address":"",
    "Add storage":"",
    "All":"",
    "are mandatory":"",
    "Cancel":"",
    "Cannot contact server: is it running and reachable?":"",
    "Canvas not supported.":"",
    "CD-ROM":"",
    "Changing language":"",
    "Close":"",
    "Community":"",
    "Compute":"",
    "Compute resource":"",
    "Compute resources are Virtual Machines attached to storage and network resources. OpenNebula Self-Service allows you to easily create, remove and manage them, including the possibility of pausing a Virtual Machine or taking a snapshot of one of their disks.":"",
    "Compute resources can be attached to these networks at creation time. Virtual machines will be provided with an IP and the correct parameters to ensure connectivity.":"",
    "Configuration":"",
    "Confirmation of action":"",
    "CPU":"",
    "Create":"",
    "Create network":"",
    "Create new compute resource":"",
    "Create new network resource":"",
    "Create new storage resource":"",
    "Create Virtual Machine":"",
    "Create # VMs":"",
    "Current resources":"",
    "Dashboard":"",
    "Datablock":"",
    "Delete":"",
    "Description":"",
    "disk id":"",
    "Disks":"",
    "Disks information":"",
    "Documentation":"",
    "Do you want to proceed?":"",
    "English":"",
    "Error":"",
    "Fields marked with":"",
    "Filesystem type":"",
    "FS type":"",
    "Have a cloudy experience!":"",
    "Human readable description of the image.":"",
    "ID":"",
    "Image":"",
    "Image information":"",
    "Image name":"",
    "images":"",
    "Images":"",
    "Info":"",
    "information":"",
    "Instance type":"",
    "In this view you can easily manage OpenNebula Network resources. You can add or remove virtual networks.":"",
    "IP":"",
    "Language":"",
    "Loading":"",
    "Loading new language... please wait":"",
    "MAC":"",
    "Make non persistent":"",
    "Make persistent":"",
    "Memory":"",
    "Monitoring information":"",
    "Name":"",
    "Name that the Image will get.":"",
    "Network":"",
    "Network Address":"",
    "Network information":"",
    "Network is unreachable: is OpenNebula running?":"",
    "Network reception":"",
    "networks":"",
    "Networks":"",
    "Networks information":"",
    "Network Size":"",
    "Network transmission":"",
    "+ New":"",
    "No disk id or image name specified":"",
    "No disks defined":"",
    "No networks defined":"",
    "OK":"",
    "OpenNebula Self-Service is a simplified user interface to manage OpenNebula compute, storage and network resources. It is focused on easiness and usability and features a limited set of operations directed towards end-users.":"",
    "Open VNC Session":"",
    "OS":"",
    "Persistence of the image":"",
    "Persistent":"",
    "Please, choose and modify the template you want to update":"",
    "Please provide a network address":"",
    "Please select":"",
    "Previous action":"",
    "Public":"",
    "Public scope of the image":"",
    "Publish":"",
    "Refresh list":"",
    "Resume":"",
    "Retrieving":"",
    "Saveas for VM with ID":"",
    "See more":"",
    "Select a template":"",
    "Select disk":"",
    "Select image to upload":"",
    "Self-Service UI Configuration":"",
    "Shutdown":"",
    "Sign out":"",
    "Size":"",
    "Size (Mb)":"",
    "Size of the datablock in MB.":"",
    "Skipping VM ":"",
    "Spanish":"",
    "State":"",
    "Stop":"",
    "Storage":"",
    "Storage pool is formed by several images. These images can contain from full operating systems to be used as base for compute resources, to simple data. OpenNebula Self-Service offers you the possibility to create or upload your own images.":"",
    "String":"",
    "style":"",
    "Submitted":"",
    "Support":"",
    "Suspend":"",
    "Take snapshot":"",
    "Target":"",
    "There are currently":"",
    "The Storage view offers you an overview of your current images. Storage elements are attached to compute resources at creation time. They can also be extracted from running virtual machines by taking an snapshot.":"",
    "This is a list of your current compute resources. Virtual Machines use previously defined images and networks. You can easily create a new compute element by cliking \'new\' and filling-in an easy wizard.":"",
    "This will cancel selected VMs":"",
    "This will delete the selected VMs from the database":"",
    "This will resume the selected VMs in stopped or suspended states":"",
    "This will shutdown the selected VMs":"",
    "This will suspend the selected VMs":"",
    "Type":"",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"",
    "Type of the image":"",
    "Unauthorized":"",
    "Unpublish":"",
    "Update":"",
    "Update template":"",
    "Used leases":"",
    "Useful links":"",
    "Virtual Machine information":"",
    "virtual machines":"",
    "Virtual Network":"",
    "Virtual Network information":"",
    "Virtual Network name missing!":"",
    "VM information":"",
    "VM Name":"",
    "VNC connection":"",
    "VNC Disabled":"",
    "Welcome":"",
    "Welcome to OpenNebula Self-Service":"",
    "You can add new storages by clicking \'new\'. Image files will be uploaded to OpenNebula and set ready to be used.":"",
    "You can also manage compute resources and perform actions such as stop, resume, shutdown or cancel.":"",
    "You have to confirm this action.":"",
    "You must select a file to upload":"",
    "You must specify a name":"",
    "You must specify size and FS type":"",
    "You need to select something.":"",
    "Your compute resources connectivity is performed using pre-defined virtual networks. You can create and manage these networks using OpenNebula Self-Service.":"",
};

==> opennebula_3.4.1.orig.tar.gz: opennebula-3.4.1/src/cloud/occi/lib/ui/public/locale/en_US/en_US.js <==
//Translated by
lang="en_US"
datatable_lang=""
locale={
    "Additionally, OpenNebula Self-Service allows easy customization of the interface (e.g. this text) and brings multi-language support.":"",
    "Additionally, you can run several operations on defined storages, such as defining their persistance. Persistent images can only be used by 1 virtual machine, and the changes made by it have effect on the base image. Non-persistent images are cloned before being used in a Virtual Machine, therefore changes are lost unless a snapshot is taken prior to Virtual Machine shutdown.":"",
    "Additionally, you can take a \'snapshot\' of the storage attached to these resources. They will be saved as new resources, visible from the Storage view and re-usable.":"",
    "Address":"",
    "Add storage":"",
    "All":"",
    "are mandatory":"",
    "Cancel":"",
    "Cannot contact server: is it running and reachable?":"",
    "Canvas not supported.":"",
    "CD-ROM":"",
    "Changing language":"",
    "Close":"",
    "Community":"",
    "Compute":"",
    "Compute resource":"",
    "Compute resources are Virtual Machines attached to storage and network resources. OpenNebula Self-Service allows you to easily create, remove and manage them, including the possibility of pausing a Virtual Machine or taking a snapshot of one of their disks.":"",
    "Compute resources can be attached to these networks at creation time. Virtual machines will be provided with an IP and the correct parameters to ensure connectivity.":"",
    "Configuration":"",
    "Confirmation of action":"",
    "CPU":"",
    "Create":"",
    "Create network":"",
    "Create new compute resource":"",
    "Create new network resource":"",
    "Create new storage resource":"",
    "Create Virtual Machine":"",
    "Create # VMs":"",
    "Current resources":"",
    "Dashboard":"",
    "Datablock":"",
    "Delete":"",
    "Description":"",
    "disk id":"",
    "Disks":"",
    "Disks information":"",
    "Documentation":"",
    "Do you want to proceed?":"",
    "English":"",
    "Error":"",
    "Fields marked with":"",
    "Filesystem type":"",
    "FS type":"",
    "Have a cloudy experience!":"",
    "Human readable description of the image.":"",
    "ID":"",
    "Image":"",
    "Image information":"",
    "Image name":"",
    "images":"",
    "Images":"",
    "Info":"",
    "information":"",
    "Instance type":"",
    "In this view you can easily manage OpenNebula Network resources. You can add or remove virtual networks.":"",
    "IP":"",
    "Language":"",
    "Launch VNC session":"",
    "Loading":"",
    "Loading new language... please wait":"",
    "MAC":"",
    "Make non persistent":"",
    "Make persistent":"",
    "Memory":"",
    "Monitoring information":"",
    "Name":"",
    "Name that the Image will get.":"",
    "Network":"",
    "Network Address":"",
    "Network information":"",
    "Network is unreachable: is OpenNebula running?":"",
    "Network reception":"",
    "networks":"",
    "Networks":"",
    "Networks information":"",
    "Network Size":"",
    "Network transmission":"",
    "+ New":"",
    "No disk id or image name specified":"",
    "No disks defined":"",
    "No networks defined":"",
    "OK":"",
    "OpenNebula Self-Service is a simplified user interface to manage OpenNebula compute, storage and network resources. It is focused on easiness and usability and features a limited set of operations directed towards end-users.":"",
    "Open VNC Session":"",
    "OS":"",
    "Persistence of the image":"",
    "Persistent":"",
    "Please, choose and modify the template you want to update":"",
    "Please provide a network address":"",
    "Please select":"",
    "Previous action":"",
    "Public":"",
    "Public scope of the image":"",
    "Publish":"",
    "Refresh list":"",
    "Resume":"",
    "Retrieving":"",
    "Saveas for VM with ID":"",
    "See more":"",
    "Select a template":"",
    "Select disk":"",
    "Select image to upload":"",
    "Self-Service UI Configuration":"",
    "Shutdown":"",
    "Sign out":"",
    "Size":"",
    "Size (Mb)":"",
    "Size of the datablock in MB.":"",
    "Skipping VM ":"",
    "Spanish":"",
    "State":"",
    "Stop":"",
    "Storage":"",
    "Storage pool is formed by several images. These images can contain from full operating systems to be used as base for compute resources, to simple data. OpenNebula Self-Service offers you the possibility to create or upload your own images.":"",
    "String":"",
    "style":"",
    "Submitted":"",
    "Support":"",
    "Suspend":"",
    "Take snapshot":"",
    "Target":"",
    "There are currently":"",
    "The Storage view offers you an overview of your current images. Storage elements are attached to compute resources at creation time. They can also be extracted from running virtual machines by taking an snapshot.":"",
    "This is a list of your current compute resources. Virtual Machines use previously defined images and networks. You can easily create a new compute element by cliking \'new\' and filling-in an easy wizard.":"",
    "This will cancel selected VMs":"",
    "This will delete the selected VMs from the database":"",
    "This will resume the selected VMs in stopped or suspended states":"",
    "This will shutdown the selected VMs":"",
    "This will suspend the selected VMs":"",
    "Type":"",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"",
    "Type of the image":"",
    "Unauthorized":"",
    "Unpublish":"",
    "Update":"",
    "Update template":"",
    "Used leases":"",
    "Useful links":"",
    "Virtual Machine information":"",
    "virtual machines":"",
    "Virtual Network":"",
    "Virtual Network information":"",
    "Virtual Network name missing!":"",
    "VM information":"",
    "VM Name":"",
    "VNC connection":"",
    "VNC Disabled":"",
    "Welcome":"",
    "Welcome to OpenNebula Self-Service":"",
    "You can add new storages by clicking \'new\'. Image files will be uploaded to OpenNebula and set ready to be used.":"",
    "You can also manage compute resources and perform actions such as stop, resume, shutdown or cancel.":"",
    "You can use the wildcard %i. When creating several VMs, %i will be replaced with a different number starting from 0 in each of them":"",
    "You have to confirm this action.":"",
    "You must select a file to upload":"",
    "You must specify a name":"",
    "You must specify size and FS type":"",
    "You need to select something.":"",
    "Your compute resources connectivity is performed using pre-defined virtual networks. You can create and manage these networks using OpenNebula Self-Service.":"",
};
